SystemOrganization addCategory: #'Stripe-Tests'!

TestCase subclass: #StripeTests
	instanceVariableNames: 'card amount plan customer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

StripeTests subclass: #StripeCardTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:33'!
testAddress1
	self assert: card address_line1 equals: '123 Main St'! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
testCVC
	self assert: card cvc equals: '123'! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testMonth
	self assert: card exp_month equals: Date today month next index asString! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testNumber
	self assert: card number size equals: 16.
	self assert: card number equals: '4242424242424242'! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
testYear
	self assert: card exp_year equals: (Date today year + 1) asString! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
testZip
	self assert: card address_zip equals: '10101'! !

StripeTests subclass: #StripeChargeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeChargeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 11:24'!
testChargeCard
	| charge |
	charge := StripeCharge newChargeFor: amount toCard: card.
	self assert: charge values notEmpty.
	self assert: (charge values at: 'amount') equals: 100.
	self assert: (charge values at: 'livemode') equals: false.
	self assert: (charge values at: 'object') equals: 'charge'.
	self assert: (charge values at: 'paid') equals: true.
	self assert: (charge values at: 'refunded') equals: false.
	self assert: (charge values at: 'card') className equals: 'StripeCard'.
	self assert: (StripeCharge instances includes: charge).
	StripeCharge instances remove: charge ifAbsent: [  ]! !

!StripeChargeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testRefundCharge
	| charge refundedCharge |
	charge := StripeCharge newChargeFor: amount toCard: card.
	self assert: (charge values at: 'amount') equals: 100.
	refundedCharge := charge refund: 51.
	self assert: (refundedCharge values at: 'amount_refunded') equals: 51.
	self assert: charge id = refundedCharge id.
	StripeCharge instances remove: charge ifAbsent: [  ]! !

!StripeChargeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testRetrieveCharge
	| charge retrievedCharge chargeId |
	charge := StripeCharge newChargeFor: amount toCard: card.
	chargeId := charge id.
	self assert: (charge values at: 'amount') equals: 100.
	retrievedCharge := charge retrieveFromStripe.
	self assert: chargeId = retrievedCharge id.
	StripeCharge instances remove: charge ifAbsent: [  ]! !

!StripeChargeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testRetrieveRecentCharges
	| charges retrievedCharge chargeId |
	charges := StripeCharge retrieveLast: 3 starting: 0.
	self assert: charges size equals: 3! !

StripeTests subclass: #StripeCouponTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeCouponTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:14'!
testCreateCoupon
	| coupon |
	coupon := self couponForTests.
	self assert: coupon id equals: '10_pct'.
	coupon deleteFromStripe! !

!StripeCouponTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:17'!
testDeleteCoupon
	| coupon |
	coupon := self couponForTests.
	self assert: coupon id equals: '10_pct'.
	coupon deleteFromStripe.
	self should: [ coupon retrieveFromStripe ] raise: StripeError! !

!StripeCouponTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:15'!
testRetrieveCoupon
	| dict coupon newCoupon |
	coupon := self couponForTests.
	self assert: coupon id equals: '10_pct'.
	newCoupon := coupon retrieveFromStripe.
	self assert: newCoupon id equals: '10_pct'! !

StripeTests subclass: #StripeCustomerTests
	instanceVariableNames: 'coupon'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:13'!
setUp
	super setUp.
	coupon := self couponForTests.
	plan := self planForTests! !

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:14'!
tearDown
	coupon deleteFromStripe.
	plan deleteFromStripe! !

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testCancelCustomerSubscription
	| cust dict |
	dict := Dictionary new.
	dict at: 'email' put: 'me@example.com'.
	dict at: 'coupon' put: '10_pct'.
	dict at: 'plan' put: 'small'.
	dict at: 'description' put: 'my name'.
	dict at: 'trial_end' put: (DateAndTime today + 30 days) asUnixTime asString.
	cust := StripeCustomer newFromCard: card with: dict.
	self assert: cust email equals: 'me@example.com'.
	self assert: cust cancelSubscriptionNow	"StripeCustomer instances remove: cust ifAbsent:[] ."! !

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testCreateCustomer
	| cust dict |
	cust := StripeCustomer newFromCard: card.
	StripeCustomer instances remove: cust ifAbsent: [  ].
	dict := Dictionary new.
	dict at: 'email' put: 'me@example.com'.
	dict at: 'coupon' put: '10_pct'.
	dict at: 'plan' put: 'small'.
	dict at: 'description' put: 'my name'.
	dict at: 'trial_end' put: (DateAndTime today + 30 days) asUnixTime asString.
	cust := StripeCustomer newFromCard: card with: dict.
	self assert: cust email equals: 'me@example.com'.
	self assert: cust coupon id equals: '10_pct'.
	self assert: cust plan id equals: 'small'.
	self assert: cust description equals: 'my name'.
	self assert: cust trial_end equals: (DateAndTime today + 30 days) asUnixTime	"StripeCustomer instances remove: cust ifAbsent:[] ."! !

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testUpdateCustomer
	| cust dict |
	dict := Dictionary new.
	dict at: 'email' put: 'me@example.com'.
	dict at: 'coupon' put: '10_pct'.
	dict at: 'plan' put: 'small'.
	dict at: 'description' put: 'my name'.
	dict at: 'trial_end' put: (DateAndTime today + 30 days) asUnixTime asString.
	cust := StripeCustomer newFromCard: card with: dict.
	self assert: cust email equals: 'me@example.com'.
	dict := Dictionary new.
	dict at: 'email' put: 'you@example.com'.
	cust := cust updateWith: dict.
	self assert: cust email equals: 'you@example.com'	"StripeCustomer instances remove: cust ifAbsent:[] ."! !

StripeTests subclass: #StripeInvoiceItemTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeInvoiceItemTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testCreateAndDelete
	| cust item |
	cust := StripeCustomer newFromCard: card.
	item := StripeInvoiceItem charge: 10 to: cust.
	self assert: item className equals: 'StripeInvoiceItem'.
	self assert: item deleteFromStripe! !

!StripeInvoiceItemTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testUpdate
	| cust item dict |
	cust := StripeCustomer newFromCard: card.
	item := StripeInvoiceItem charge: 10 to: cust.
	self assert: item className equals: 'StripeInvoiceItem'.
	self assert: item amount equals: 10.
	item updateAmountTo: 25.
	self assert: item amount equals: 25! !

StripeTests subclass: #StripeInvoiceTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeInvoiceTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 15:18'!
setUp
	super setUp.
	customer := self customerForTests.
	plan := self planForTests! !

!StripeInvoiceTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 15:18'!
tearDown
	customer deleteFromStripe.
	plan deleteFromStripe! !

!StripeInvoiceTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 15:40'!
testGetUpcomingInvoice
	| invoice |
	customer updateSubscriptionTo: plan.
	invoice := customer getUpcomingInvoice.
	self assert: invoice className equals: 'StripeInvoice'! !

StripeTests subclass: #StripePlanTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripePlanTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:03'!
setUp
	super setUp.
	plan := self planForTests! !

!StripePlanTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:03'!
tearDown
	plan deleteFromStripe! !

!StripePlanTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:04'!
testCreatePlan
	self assert: plan id equals: 'small'! !

StripeTests subclass: #StripeSubscriptionTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeSubscriptionTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 15:16'!
setUp
	super setUp.
	plan := self planForTests.
	customer := self customerForTests! !

!StripeSubscriptionTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 15:16'!
tearDown
	customer deleteFromStripe.
	plan deleteFromStripe! !

!StripeSubscriptionTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 15:44'!
testSubscribeAndRemoveCustomer
	customer updateSubscriptionTo: plan.
	self assert: customer subscription plan equals: plan! !

StripeTests subclass: #StripeSystemTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeSystemTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testObjectsToIds
	| ids |
	ids := StripeSystem objectsToIds: card values.
	self assert: ids notEmpty! !

!StripeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 16:13'!
couponForTests
	| dict |
	dict := Dictionary new.
	dict at: 'id' put: '10_pct'.
	dict at: 'percent_off' put: '10'.
	dict at: 'duration' put: 'repeating'.
	dict at: 'duration_in_months' put: '3'.
	dict at: 'max_redemptions' put: '10'.
	dict at: 'redeem_by' put: (DateAndTime today + 60 days) asUnixTime asString.
	^ StripeCoupon newFrom: dict! !

!StripeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 5/15/2012 15:11'!
customerForTests
	| dict |
	dict := Dictionary new.
	dict at: 'email' put: 'me@example.com'.
	dict at: 'description' put: 'my name'.
	^ StripeCustomer newFromCard: card with: dict! !

!StripeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
planForTests
	| dict |
	dict := Dictionary new.
	dict at: 'id' put: 'small'.
	dict at: 'amount' put: '1000'.
	dict at: 'currency' put: 'usd'.
	dict at: 'interval' put: 'month'.
	dict at: 'name' put: 'Small Plan'.
	dict at: 'trial_period_days' put: '30'.
	^ StripePlan newFrom: dict! !

!StripeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
setUp
	card := StripeCard new
		number: '4242424242424242';
		exp_month: Date today month next index asString;
		exp_year: (Date today year + 1) asString;
		cvc: '123';
		address_line1: '123 Main St';
		address_zip: '10101'.
	amount := '100'! !

StripeTests subclass: #StripeTokenTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeTokenTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 6/1/2012 17:07'!
testCreateToken
	| token |
	token := StripeToken newFrom: card for: '200'.
	self assert: token className equals: 'StripeToken'! !
